@@ -9,6 +9,7 @@ use Data::Dumper;
 use Digest::SHA qw(hmac_sha256_base64 sha256_base64);
 use POSIX qw(strftime);
 use Data::UUID;
+use Config::IniFiles;
 
 =head1 NAME
 
@@ -20,18 +21,16 @@ Version 1.0
 
 =cut
 
-our $VERSION = '1.0.3';
+our $VERSION = '1.0.5';
 
 =head1 SYNOPSIS
 
     use Akamai::Edgegrid;
 
-    my $baseurl = 'https://akaa-bbbbbbbbbbbbb.luna.akamaiapis.net';
     my $agent = new Akamai::Edgegrid(
-        client_token => 'cccccccccccccccc',
-        client_secret => 'sssssssssssssssss',
-        access_token => 'aaaaaaaaaaaaaaaaaaaa'
-    );
+                    config_file => "$ENV{HOME}/.edgerc",
+                    section   => "default");
+    my $baseurl = "https://" . $agent->{host};
 
     my $resp = $agent->get("$baseurl/diagnostic-tools/v1/locations");
     print $resp->content;
@@ -208,32 +207,52 @@ sub new {
     my $class = shift @_;
     my %args = @_;
 
-    my @local_args = qw(client_token client_secret access_token headers_to_sign max_body debug);
+    my @local_args = qw(config_file section client_token client_secret access_token headers_to_sign max_body debug);
     my @required_args = qw(client_token client_secret access_token);
+    my @cred_args = qw(client_token client_secret access_token host);
     my %local = ();
 
     for my $arg (@local_args) {
         $local{$arg} = delete $args{$arg};
     }
-    
+
     my $self = LWP::UserAgent::new($class, %args);
 
     for my $arg (@local_args) {
         $self->{$arg} = $local{$arg};
     }
 
+    # defaults
+    unless ($self->{config_file}) {
+        $self->{config_file} = "$ENV{HOME}/.edgerc";
+    }
+    if (-f $self->{config_file} and $self->{section} ) {
+        my $cfg = Config::IniFiles->new( -file => $self->{config_file} );
+        for my $variable (@cred_args) {
+            if ($cfg->val($self->{section}, $variable)) {
+                $self->{$variable} = $cfg->val($self->{section}, $variable);
+            } else {
+                die ("Config file " .  $self->{config_file} .
+                    " is missing required argument " . $variable .
+                    " in section " . $self->{section} );
+            }
+        }
+        if ( $cfg->val($self->{section}, "max_body") ) {
+            $self->{max_body} = $cfg->val($self->{section}, "max_body");
+        }
+    }
+
     for my $arg (@required_args) {
-        unless ($self->{$arg}) {
+    unless ($self->{$arg}) {
             die "missing required argument $arg";
         }
     }
 
-    # defaults
     unless ($self->{headers_to_sign}) {
         $self->{headers_to_sign} = [];
     }
     unless ($self->{max_body}) {
-        $self->{max_body} = 2048;
+        $self->{max_body} = 131072;
     }
 
     $self->add_handler('request_prepare' => sub {
